"""Module dedicated to clustering algorithms.
"""

from .kmeans import ModKMeans  # noqa: F401

__all__ = ("ModKMeans",)
